==> loadmychunks-1.2.0%2B1.19.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/util/Message.java <==
package com.drathonix.loadmychunks.common.util;

import com.mojang.brigadier.context.CommandContext;
import net.minecraft.class_124;
import net.minecraft.class_2168;
import net.minecraft.class_2558;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_3222;
import net.minecraft.class_5250;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

//? if <1.18.3 {
/*import net.minecraft.network.chat.TranslatableComponent;
import net.minecraft.network.chat.TextComponent;
import net.minecraft.Util;
*///?}

/**
 * Multi-versioning abstraction utility class for Components/Chat
 */
public class Message {
    /**
     * Creates a translatable Component
     * @param key the translation key
     * @param args the translation arguments
     * @return a MutableComponent containing translatable contents.
     */
    public static @NotNull class_5250 translatable(@NotNull String key, Object... args) {
        //? if <1.18.3 {
        /*return new TranslatableComponent(key,args);
        *///?}
        //? if >1.18.2 {
        return class_2561.method_43469(key,args);
        //?}
    }

    /**
     * Sends a system message to a player.
     * @param player the recipient.
     * @param message the message.
     */
    public static void send(@NotNull class_3222 player, @Nullable class_2561 message) {
        if(message == null){
            return;
        }
        //? if >1.18.2 {
        player.method_43496(message);
        //?} else {
        /*player.sendMessage(message, Util.NIL_UUID);
        *///?}
    }

    /**
     * Sends a success message to a command source.
     * @param ctx the command context.
     * @param message the success message
     */
    public static void sendSuccess(@NotNull CommandContext<class_2168> ctx, @NotNull class_2561 message) {
        //? if <1.20.1 {
        ctx.getSource().method_9226(message,true);
        //?} else if >=1.20.1 && !forge {
        /*ctx.getSource().sendSuccess(()->message,true);
        *///?} else if >=1.20.1 && forge {
        /*ctx.getSource().sendSystemMessage(message);
        *///?}
    }

    /**
     * Styles a component.
     * @param component the component to style.
     * @param formatting the color
     * @param bold whether to bold the text.
     * @param underlined whether to underline the text.
     * @return the styled component.
     */
    public static @NotNull class_5250 styled(@NotNull class_5250 component, @NotNull class_124 formatting, boolean bold, boolean underlined) {
        return component.method_10862(class_2583.field_24360.method_10977(formatting).method_10982(bold).method_30938(underlined));
    }

    /**
     * Sends a system message to a command source.
     * @param ctx the command context.
     * @param component the message.
     */
    public static void sendSystem(@NotNull CommandContext<class_2168> ctx, @NotNull class_2561 component) {
        //? if <1.19.2 {
        /*sendSuccess(ctx,component);
        *///?} else {
        ctx.getSource().method_45068(component);
        //?}
    }

    /**
     * Sets the component on click to suggest a command.
     * @param component the component.
     * @param command the suggested command.
     * @return the component with the click command.
     */
    public static @NotNull class_5250 clickCommand(@NotNull class_5250 component, @NotNull String command) {
        return component.method_10862(component.method_10866().method_10958(new class_2558(class_2558.class_2559.field_11745,command)));
    }

    /**
     * Creates an empty component.
     * @return a new empty component.
     */
    public static class_5250 empty() {
        return literal("");
    }

    /**
     * Creates a literal text component.
     * @param text the text.
     * @return a Text Component
     */
    public static class_5250 literal(String text) {
        //? if <1.18.3 {
        /*return new TextComponent(text);
         *///?}
        //? if >1.18.2 {
        return class_2561.method_43470(text);
        //?}
    }

    public static class_5250 append(@NotNull class_5250 m1, @NotNull class_2561 m2) {
        return m1.method_10852(m2);
    }

    public static class_5250 append(class_5250 m1, String str) {
        return m1.method_27693(str);
    }
}

==> loadmychunks-1.2.1%2B1.20.6%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/util/Message.java <==
package com.drathonix.loadmychunks.common.util;

import com.mojang.brigadier.context.CommandContext;
import net.minecraft.class_124;
import net.minecraft.class_2168;
import net.minecraft.class_2558;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_3222;
import net.minecraft.class_5250;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

//? if <1.18.3 {
/*import net.minecraft.network.chat.TranslatableComponent;
import net.minecraft.network.chat.TextComponent;
import net.minecraft.Util;
*///?}

/**
 * Multi-versioning abstraction utility class for Components/Chat
 */
public class Message {
    /**
     * Creates a translatable Component
     * @param key the translation key
     * @param args the translation arguments
     * @return a MutableComponent containing translatable contents.
     */
    public static @NotNull class_5250 translatable(@NotNull String key, Object... args) {
        //? if <1.18.3 {
        /*return new TranslatableComponent(key,args);
        *///?}
        //? if >1.18.2 {
        return class_2561.method_43469(key,args);
        //?}
    }

    /**
     * Sends a system message to a player.
     * @param player the recipient.
     * @param message the message.
     */
    public static void send(@NotNull class_3222 player, @Nullable class_2561 message) {
        if(message == null){
            return;
        }
        //? if >1.18.2 {
        player.method_43496(message);
        //?} else {
        /*player.sendMessage(message, Util.NIL_UUID);
        *///?}
    }

    /**
     * Sends a success message to a command source.
     * @param ctx the command context.
     * @param message the success message
     */
    public static void sendSuccess(@NotNull CommandContext<class_2168> ctx, @NotNull class_2561 message) {
        //? if <1.20.1 {
        /*ctx.getSource().sendSuccess(message,true);
        *///?} else if >=1.20.1 && !forge {
        ctx.getSource().method_9226(()->message,true);
        //?} else if >=1.20.1 && forge {
        /*ctx.getSource().sendSystemMessage(message);
        *///?}
    }

    /**
     * Styles a component.
     * @param component the component to style.
     * @param formatting the color
     * @param bold whether to bold the text.
     * @param underlined whether to underline the text.
     * @return the styled component.
     */
    public static @NotNull class_5250 styled(@NotNull class_5250 component, @NotNull class_124 formatting, boolean bold, boolean underlined) {
        return component.method_10862(class_2583.field_24360.method_10977(formatting).method_10982(bold).method_30938(underlined));
    }

    /**
     * Sends a system message to a command source.
     * @param ctx the command context.
     * @param component the message.
     */
    public static void sendSystem(@NotNull CommandContext<class_2168> ctx, @NotNull class_2561 component) {
        //? if <1.19.2 {
        /*sendSuccess(ctx,component);
        *///?} else {
        ctx.getSource().method_45068(component);
        //?}
    }

    /**
     * Sets the component on click to suggest a command.
     * @param component the component.
     * @param command the suggested command.
     * @return the component with the click command.
     */
    public static @NotNull class_5250 clickCommand(@NotNull class_5250 component, @NotNull String command) {
        return component.method_10862(component.method_10866().method_10958(new class_2558(class_2558.class_2559.field_11745,command)));
    }

    /**
     * Creates an empty component.
     * @return a new empty component.
     */
    public static class_5250 empty() {
        return literal("");
    }

    /**
     * Creates a literal text component.
     * @param text the text.
     * @return a Text Component
     */
    public static class_5250 literal(String text) {
        //? if <1.18.3 {
        /*return new TextComponent(text);
         *///?}
        //? if >1.18.2 {
        return class_2561.method_43470(text);
        //?}
    }

    public static class_5250 append(@NotNull class_5250 m1, @NotNull class_2561 m2) {
        return m1.method_10852(m2);
    }

    public static class_5250 append(class_5250 m1, String str) {
        return m1.method_27693(str);
    }
}
